config

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 27, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	ScanPaths      []string `toml:"scan_paths"`
	ScanOrphans    bool     `toml:"scan_orphans"`
	HideSidechains bool     `toml:"hide_sidechains"`
	SortBy         string   `toml:"sort_by"`
}

func Load

func Load() (Config, bool, error)

Load reads the config file, creating a default one if it doesn't exist. Returns the config and a boolean indicating whether the program should exit (e.g. first run or empty scan_paths).

Jump to