Discover Packages
github.com/achton/cc360
internal
config
package
Version:
v0.5.0
Opens a new window with list of versions in this module.
Published: May 27, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Config struct {
ScanPaths []string `toml:"scan_paths"`
ScanOrphans bool `toml:"scan_orphans"`
HideSidechains bool `toml:"hide_sidechains"`
SortBy string `toml:"sort_by"`
}
Load reads the config file, creating a default one if it doesn't exist.
Returns the config and a boolean indicating whether the program should exit
(e.g. first run or empty scan_paths).
Source Files
¶
Click to show internal directories.
Click to hide internal directories.